<template>
  <div class="memeber-manage">
    <div class="left">
      <TreeLeft @editDepartmentClick="editDepartmentClick" />
    </div>
    <div class="right">
      <SearchCommonView
        ref="searchCommonView"
        :query-class-options="queryClassOptions"
        :search-options="searchOptions"
      />
      <div class="btn-pager">
        <PublicFunctionBtnView
          :allocation="false"
          :receive="false"
          :delete-button="false"
          :import-button="false"
          :department-set="true"
          :data-range="true"
          :login-control="true"
          :operates-list="operatesList"
        />
        <PagerView class="page" />
      </div>
      <TableCommonView ref="tableListRef" :table-list="tableList">
        <template slot="tableButton">
          <el-table-column label="操作" width="160">
            <template slot-scope="scope">
              <el-button @click="editClick(scope.row)" type="text" size="small">编辑</el-button>
              <el-button v-if="!scope.row.enableStatus" @click="enableClick(scope.row)" type="text" size="small"
                >启用</el-button
              >
              <el-button v-else @click="stopClick(scope.row)" type="text" size="small">停用</el-button>
              <el-button @click="copyClick(scope.row)" type="text" size="small">复制</el-button>
              <el-button @click="deleteClick(scope.row)" type="text" size="small">删除</el-button>
            </template>
          </el-table-column>
        </template>
      </TableCommonView>
    </div>

    <!-- 新建/编辑 -->
    <AddMemberManageDialog v-if="editConfig.visible" :edit-common-config="editConfig" />
    <!-- 编辑部门 -->
    <EditDepartmentDialog v-if="departmentConfig.visible" :edit-department-config="departmentConfig" />
  </div>
</template>

<script>
import AddMemberManageDialog from "@/views/backgroundConfig/memberManage/AddMemberManageDialog"
import TreeLeft from "@/views/backgroundConfig/memberManage/TreeLeft"
import EditDepartmentDialog from "@/views/backgroundConfig/memberManage/EditDepartmentDialog"

export default {
  name: "MemberManage",
  props: {},
  components: {
    AddMemberManageDialog,
    TreeLeft,
    EditDepartmentDialog
  },
  computed: {
    searchCommonHeight() {
      return this.$refs.searchCommonView.offsetHeight
    }
  },
  data() {
    return {
      tableList: {},
      queryClassOptions: [
        { value: "1", label: "全部" },
        { value: "2", label: "已批准" },
        { value: "3", label: "审批中" },
        { value: "4", label: "未提交" },
        { value: "5", label: "已驳回" },
        { value: "6", label: "已拒绝" }
      ],
      searchOptions: [],
      operatesList: [
        { id: "1", name: "共享" },
        { id: "2", name: "批量编辑" },
        { id: "3", name: "导出" },
        { id: "4", name: "下载全部附件" },
        { id: "5", name: "更改创建人" },
        { id: "6", name: "树结构设置" },
        { id: "7", name: "审批设置" },
        { id: "8", name: "恢复预设列宽" }
      ],
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      departmentConfig: {
        visible: false,
        title: "编辑部门",
        infomation: {}
      }
    }
  },
  created() {
    this.setTable()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [
          {
            name: "小刘",
            account: "xiaoliu",
            department: "市场部",
            creator: "系统管理员",
            rolePermssion: "主管",
            phone: "18511112222",
            email: "xiaoliu@aaa.ccom",
            isAdmin: "是",
            state: "在职",
            enableStatus: true
          }
        ],
        tableColumn: [
          { label: "姓名", prop: "name", sortable: true, min: 120 },
          { label: "账号", prop: "account", min: 90 },
          { label: "部门", prop: "department" },
          { label: "角色权限", prop: "rolePermssion", min: 100 },
          { label: "手机", prop: "phone" },
          { label: "Email", prop: "email" },
          { label: "是否管理员", prop: "isAdmin", min: 100 },
          { label: "状态", prop: "state" }
        ]
      }
      this.searchOptions = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        const label = this.tableList.tableColumn[i].label
        this.searchOptions.push({ value: (i + 1).toString(), label: label })
      }
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      this.editConfig.infomation = {
        account: "",
        isAdmin: "",
        password: "",
        passwordConfirm: "",
        name: "",
        realName: "",
        department: "",
        state: "",
        phone: "",
        telephone: "",
        email: "",
        wechat: "",
        approvalDelegation: "",
        miniProgram: "",
        dingtalk: "",
        approvalPrincipal: "",
        positionLevel: "",
        notes: "",
        employeeDate: "",
        avatar: "",
        cloudHome: "",
        determine: "",
        rolePermssion: "",
        dataScope: "",
        role1: "",
        role2: "",
        role3: "",
        role4: "",
        role5: "",
        role6: "",
        role7: "",
        role8: "",
        other1: "",
        other2: ""
      }
    },
    // 编辑
    editClick(row) {
      console.log(row)
      this.editConfig.visible = true
      this.editConfig.title = "编辑"
      this.editConfig.infomation = {
        account: "",
        isAdmin: "",
        password: "",
        passwordConfirm: "",
        name: "",
        realName: "",
        department: "",
        state: "",
        phone: "",
        telephone: "",
        email: "",
        wechat: "",
        approvalDelegation: "",
        miniProgram: "",
        dingtalk: "",
        approvalPrincipal: "",
        positionLevel: "",
        notes: "",
        employeeDate: "",
        avatar: "",
        cloudHome: "",
        determine: "",
        rolePermssion: "",
        dataScope: "",
        role1: "",
        role2: "",
        role3: "",
        role4: "",
        role5: "",
        role6: "",
        role7: "",
        role8: "",
        other1: "",
        other2: ""
      }
    },
    // 启用
    enableClick(row) {
      console.log(row)
    },
    // 停用
    stopClick(row) {
      console.log(row)
    },
    // 复制
    copyClick(row) {
      console.log(row)
    },
    // 删除
    deleteClick(row) {
      console.log(row)
    },
    // 编辑部门
    editDepartmentClick(command, data) {
      console.log(command, data)
      if (command === "edit") {
        this.departmentConfig.visible = true
        this.departmentConfig.infomation = {
          departmentName: data.label,
          departmentNumber: data.id,
          notes: ""
        }
      } else if (command === "add") {
        this.departmentConfig.visible = true
        this.departmentConfig.infomation = {
          departmentName: "",
          departmentNumber: "",
          notes: ""
        }
      }
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.memeber-manage {
  display: flex;
  .left {
    width: 260px;
    height: 100vh;
    border-right: 1px solid #ebeef5;
  }
  .right {
    flex: 1;
    .btn-pager {
      display: flex;
      .page {
        margin-left: auto;
      }
    }
  }
}
</style>
